package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.FileStorageServicesMapper;
import com.zyc.system.domain.FileStorageServices;
import com.zyc.system.service.IFileStorageServicesService;

/**
 * 文件存储服务Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class FileStorageServicesServiceImpl implements IFileStorageServicesService 
{
    @Autowired
    private FileStorageServicesMapper fileStorageServicesMapper;

    /**
     * 查询文件存储服务
     * 
     * @param id 文件存储服务主键
     * @return 文件存储服务
     */
    @Override
    public FileStorageServices selectFileStorageServicesById(Integer id)
    {
        return fileStorageServicesMapper.selectFileStorageServicesById(id);
    }

    /**
     * 查询文件存储服务列表
     * 
     * @param fileStorageServices 文件存储服务
     * @return 文件存储服务
     */
    @Override
    public List<FileStorageServices> selectFileStorageServicesList(FileStorageServices fileStorageServices)
    {
        return fileStorageServicesMapper.selectFileStorageServicesList(fileStorageServices);
    }

    /**
     * 新增文件存储服务
     * 
     * @param fileStorageServices 文件存储服务
     * @return 结果
     */
    @Override
    public int insertFileStorageServices(FileStorageServices fileStorageServices)
    {
        return fileStorageServicesMapper.insertFileStorageServices(fileStorageServices);
    }

    /**
     * 修改文件存储服务
     * 
     * @param fileStorageServices 文件存储服务
     * @return 结果
     */
    @Override
    public int updateFileStorageServices(FileStorageServices fileStorageServices)
    {
        return fileStorageServicesMapper.updateFileStorageServices(fileStorageServices);
    }

    /**
     * 批量删除文件存储服务
     * 
     * @param ids 需要删除的文件存储服务主键
     * @return 结果
     */
    @Override
    public int deleteFileStorageServicesByIds(Integer[] ids)
    {
        return fileStorageServicesMapper.deleteFileStorageServicesByIds(ids);
    }

    /**
     * 删除文件存储服务信息
     * 
     * @param id 文件存储服务主键
     * @return 结果
     */
    @Override
    public int deleteFileStorageServicesById(Integer id)
    {
        return fileStorageServicesMapper.deleteFileStorageServicesById(id);
    }
}
